@@ -30,12 +30,15 @@ def get_page_meta(page, language):
         meta = Meta()
         title = page.get_title_obj(language)
 
-        meta.title = page.get_title(language)
+        meta.title = page.get_page_title(language)
+        if not meta.title:
+            meta.title = page.get_title(language)
 
         try:
             titlemeta = title.titlemeta
             meta.description = titlemeta.description.strip()
-            meta.keywords = titlemeta.keywords.strip().split(",")
+            if titlemeta.keywords:
+                meta.keywords = titlemeta.keywords.strip().split(",")
             meta.locale = titlemeta.locale
             meta.og_description = titlemeta.og_description.strip()
             meta.twitter_description = titlemeta.twitter_description.strip()
@@ -64,12 +67,6 @@ def get_page_meta(page, language):
                 meta.og_publisher = pagemeta.og_publisher
                 if pagemeta.og_author_url:
                     meta.og_author_url = pagemeta.og_author_url
-                elif pagemeta.og_author:
-                    meta.og_author = {
-                        'first_name': pagemeta.og_author.first_name,
-                        'last_name': pagemeta.og_author.last_name
-                    }
-
                 try:
                     from djangocms_page_meta.utils import get_title_tags, get_page_meta
                     tags = get_title_tags(page, language)
@@ -86,4 +83,4 @@ def get_page_meta(page, language):
         if not meta.description and page.get_meta_description(language):
             meta.description = page.get_meta_description(language).strip()
         meta.url = page.get_absolute_url(language)
-    return meta
\ No newline at end of file
+    return meta
